==> nextcloud-14.0.1.tgz: nextcloud/apps/systemtags/l10n/lv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Atzīmes",
    "Update" : "Atjaunināt",
    "Create" : "Izveidot",
    "Select tag…" : "Izvēlies atzīmi...",
    "Tagged files" : "Atzīmētās datnes",
    "Select tags to filter by" : "Izvēlies atzīmes pēc kā filtrēt",
    "No tags found" : "Netika atrasta neviena atzīme",
    "Please select tags to filter by" : "Lūdzu izvēlies atzīmes pēc kā filtrēt",
    "No files found for the selected tags" : "Datnes ar atlasītām atzīmēm netika atrastas",
    "Added system tag %1$s" : "Pievienota sistēmas atzīme %1$s",
    "Added system tag {systemtag}" : "Pievienota sistēmas atzīme  {systemtag}",
    "%1$s added system tag %2$s" : "%1$s pievienota sistēmas atzīme %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pievienota sistēmas atzīme {systemtag}",
    "Removed system tag %1$s" : "Noņemta sistēmas atzīme %1$s",
    "Removed system tag {systemtag}" : "Noņemta sistēmas atzīme {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s noņēma sistēmas atzīmi %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} noņēma sistēmas atzīmi {systemtag}",
    "You created system tag %1$s" : "Tu izveidoji sistēmas atzīmi  %1$s",
    "You created system tag {systemtag}" : "Tu izveidoji sistēmas atzīmi  {systemtag}",
    "%1$s created system tag %2$s" : "%1$s izveidoja sistēmas atzīmi %2$s",
    "{actor} created system tag {systemtag}" : "{actor} izveidoja sistēmas atzīmi {systemtag}",
    "You deleted system tag %1$s" : "Tu izdzēsi sistēmas atzīmi %1$s",
    "You deleted system tag {systemtag}" : "Tu izdzēsi sistēmas atzīmi {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s izdzēsa sistēmas atzīmi %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izdzēsa sistēmas atzīmi {systemtag}",
    "You updated system tag %2$s to %1$s" : "Tu atjaunoji sistēmas atzīmi %2$s uz %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atjaunināt sistēmas atzīmi {oldsystemtag} uz {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$spārmainija sistēmas atzīmi %3$s uz %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atjaunināja sistēmas atzīmi {oldsystemtag} uz {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Tu pievienoji sistēmas atzīmi %2$s uz %1$s",
    "You added system tag {systemtag} to {file}" : "Tu pievienoji sistēmas atzīmi {systemtag} datnei {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$spievienoja sistēmas atzīmi %3$s uz %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pievienoja sistēmas atzīmi {systemtag} {file}",
    "You removed system tag %2$s from %1$s" : "Tu noņēmi sistēmas atzīmi %2$s no %1$s",
    "You removed system tag {systemtag} from {file}" : "Tu noņēmi sistēmas atzīmi {systemtag} no {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s noņēma sistēmas atzīmi %3$s no %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} noņēma sistēmas atzīmi {systemtag} no {file}",
    "%s (restricted)" : "%s (ierobežots)",
    "%s (invisible)" : "%s (neredzams)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistēmas atzīmes</strong> failam tikušas mainītas",
    "Collaborative tags" : "Sadarbības atzīmes",
    "Select tag …" : "Izvēlies atzīmi...",
    "Name" : "Nosaukums",
    "Public" : "Publisks",
    "Restricted" : "Ierobežots",
    "Invisible" : "Neredzams",
    "Delete" : "Dzēst",
    "Reset" : "Atiestatīt",
    "No files in here" : "Šeit nav datņu",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "Create and edit collaborative tags. These tags affect all users." : "Izveido un rediģē sadarbības atzīmes. Šīs atzīmes ietekmē visus lietotājus."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/systemtags/l10n/lv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Atzīmes",
    "Update" : "Atjaunināt",
    "Create" : "Izveidot",
    "Select tag…" : "Izvēlies atzīmi...",
    "Added system tag {systemtag}" : "Pievienota sistēmas atzīme  {systemtag}",
    "Added system tag %1$s" : "Pievienota sistēmas atzīme %1$s",
    "%1$s added system tag %2$s" : "%1$s pievienota sistēmas atzīme %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pievienota sistēmas atzīme {systemtag}",
    "Removed system tag {systemtag}" : "Noņemta sistēmas atzīme {systemtag}",
    "Removed system tag %1$s" : "Noņemta sistēmas atzīme %1$s",
    "%1$s removed system tag %2$s" : "%1$s noņēma sistēmas atzīmi %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} noņēma sistēmas atzīmi {systemtag}",
    "You created system tag %1$s" : "Tu izveidoji sistēmas atzīmi  %1$s",
    "You created system tag {systemtag}" : "Tu izveidoji sistēmas atzīmi  {systemtag}",
    "%1$s created system tag %2$s" : "%1$s izveidoja sistēmas atzīmi %2$s",
    "{actor} created system tag {systemtag}" : "{actor} izveidoja sistēmas atzīmi {systemtag}",
    "You deleted system tag %1$s" : "Jūs izdzēsāt sistēmas atzīmi %1$s",
    "You deleted system tag {systemtag}" : "Jūs izdzēsāt sistēmas atzīmi {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s izdzēsa sistēmas atzīmi %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izdzēsa sistēmas atzīmi {systemtag}",
    "You updated system tag %2$s to %1$s" : "Tu atjaunoji sistēmas atzīmi %2$s uz %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atjaunināt sistēmas atzīmi {oldsystemtag} uz {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$spārmainija sistēmas atzīmi %3$s uz %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atjaunināja sistēmas atzīmi {oldsystemtag} uz {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Tu pievienoji sistēmas atzīmi %2$s uz %1$s",
    "You added system tag {systemtag} to {file}" : "Tu pievienoji sistēmas atzīmi {systemtag} datnei {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$spievienoja sistēmas atzīmi %3$s uz %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pievienoja sistēmas atzīmi {systemtag} {file}",
    "You removed system tag %2$s from %1$s" : "Tu noņēmi sistēmas atzīmi %2$s no %1$s",
    "You removed system tag {systemtag} from {file}" : "Tu noņēmi sistēmas atzīmi {systemtag} no {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s noņēma sistēmas atzīmi %3$s no %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} noņēma sistēmas atzīmi {systemtag} no {file}",
    "%s (restricted)" : "%s (ierobežots)",
    "%s (invisible)" : "%s (neredzams)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistēmas atzīmes</strong> failam tikušas mainītas",
    "Collaborative tags" : "Sadarbības atzīmes",
    "Tagged files" : "Atzīmētās datnes",
    "Select tags to filter by" : "Izvēlies atzīmes pēc kā filtrēt",
    "No tags found" : "Netika atrasta neviena atzīme",
    "Please select tags to filter by" : "Lūdzu izvēlies atzīmes pēc kā filtrēt",
    "No files found for the selected tags" : "Datnes ar atlasītām atzīmēm netika atrastas",
    "Select tag …" : "Izvēlies atzīmi...",
    "Name" : "Nosaukums",
    "Public" : "Publisks",
    "Restricted" : "Ierobežots",
    "Invisible" : "Neredzams",
    "Delete" : "Dzēst",
    "Reset" : "Atiestatīt",
    "No files in here" : "Šeit nav datņu",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "Create and edit collaborative tags. These tags affect all users." : "Izveido un rediģē sadarbības atzīmes. Šīs atzīmes ietekmē visus lietotājus."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
